<?php

###############################################################################
# serbian.php
# This is the Serbian (latin) language file for Geeklog!
# Special thanks to GOSC which motivated me to contribute to Geeklog project.
#
# By: Aleksandar Scepanovic 2009
# Contact email: ascepanovic@gmail.com
# WEB: http://www.scepanovic.info
#
# NAPOMENA: Prosto je nemoguce uskladiti prevod da svi korisnic budu zadovoljni
# ako imate bilo koji predlog za izmenu prevoda ili ste uocili gresku molim
# da me kontaktirate kako bi ista bila ispravljena
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

$LANG_CHARSET = 'iso-8859-2';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => 'Autor:',
    2 => 'detaljnije',
    3 => 'komentar(a)',
    4 => 'Izmeni',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => 'Za Administratora:',
    10 => 'Zahtevi',
    11 => 'Tekst(a)',
    12 => 'Blokovi',
    13 => 'Kategorije',
    14 => '',
    15 => '',
    16 => '',
    17 => 'Korisnici',
    18 => 'SQL upit',
    19 => 'Odjava',
    20 => 'Korisnicke postavke:',
    21 => 'Korisnicko ime',
    22 => 'Korisnicki ID',
    23 => 'Sigurnosni nivo',
    24 => 'Anonimni korisnik',
    25 => 'Odgovori',
    26 => 'Prikazani komentari su vlasnistvo autora istih. Mi nismo odgovorni za njihov sadrzaj',
    27 => 'Najnoviji tekst',
    28 => 'Obrisi',
    29 => 'Nema korisnickih komentara.',
    30 => 'Stariji tekstovi',
    31 => 'Dozvoljeni HTML kodovi:',
    32 => 'Greska, korisnicko ime nije ispravno',
    33 => 'Greska, ne mogu pisati u log fajlove',
    34 => 'Greska',
    35 => 'Odjavi se',
    36 => 'on',
    37 => 'Nema korisnickih tekstova',
    38 => 'RSS',
    39 => 'Osvezi',
    40 => 'Imate <tt>register_globals = Off</tt> u vasem <tt>php.ini</tt> fajlu. Geeklog zahteva da promenjiva <tt>register_globals</tt> bude <strong>on</strong>. Pre nego sto nastavite, molimo vas izvrsite izmene i restartujte web server.',
    41 => 'Gosti',
    42 => 'Autor:',
    43 => 'Odgovori na ovo',
    44 => 'Roditelj',
    45 => 'MySQL greska broj',
    46 => 'MySQL poruka greske',
    47 => 'Korisnici',
    48 => 'Korisnicke postavke',
    49 => 'Moj nalog',
    50 => 'Greska u SQL naredbi',
    51 => 'pomoc',
    52 => 'Novi',
    53 => 'Administracija',
    54 => 'Ne mogu otvoriti log fajl.',
    55 => 'Greska u',
    56 => 'Glasaj',
    57 => 'Lozinka',
    58 => 'Prijava',
    59 => "Nemate korisnicki nalog? Kreirajte ga besplatno <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">Ovde</a>",
    60 => 'Posaljite komentar',
    61 => 'Kreiraj Novi Nalog',
    62 => 'reci',
    63 => 'Postavke komentara',
    64 => 'Posalji tekst prijatelju',
    65 => 'Pogledaj verziju za stampu',
    66 => '',
    67 => 'Dobrodosli na ',
    68 => 'Pocetna',
    69 => 'Kontakt',
    70 => 'Pretraga',
    71 => 'Doprinesi',
    72 => 'Web izvori',
    73 => '',
    74 => '',
    75 => 'Napredna pretraga',
    76 => 'Statistika web stranice',
    77 => 'Pluginovi',
    78 => '',
    79 => 'Sta je novo',
    80 => 'tekst(ovi) u poslednjih',
    81 => 'tekst(ova) u zadnjih',
    82 => 'sati',
    83 => 'Komentari',
    84 => '',
    85 => 'poslednjih 48 sati',
    86 => 'Nema novih komentara',
    87 => 'poslednje 2 sedmice',
    88 => '',
    89 => '',
    90 => 'Pocetna stranica',
    91 => 'Stranica generisana za',
    92 => 'sekundi',
    93 => 'Copyright',
    94 => 'Svi zastitni znakovi i autorska prava pripadaju vlasnicima istih',
    95 => 'Sajt pokrece',
    96 => 'Korisnicke grupe',
    97 => 'Lista reci',
    98 => 'Pluginovi',
    99 => 'Tekstovi',
    100 => 'Nema novih tekstova',
    101 => '',
    102 => '',
    103 => 'Sigurnosne Kopije',
    104 => 'od',
    105 => 'Posalji emali korisnicima',
    106 => 'Ukupno pregleda:',
    107 => 'Provera Geeklog verzije',
    108 => 'Obrisi Cache',
    109 => 'Prijavi zloupotrebu',
    110 => 'Prijavi ovaj tekst administratoru',
    111 => '',
    112 => 'Registrovani Korisnici',
    113 => 'Dokumentacija',
    114 => 'TRACKBACKS',
    115 => 'Nema novih trackback komentara',
    116 => 'Trackback',
    117 => 'Katalog',
    118 => 'Nastavi sa citanjem na sledecoj strani:',
    119 => "Zaboravili ste <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\" rel=\"nofollow\">lozinku</a>?",
    120 => 'Direktan link za komentar',
    121 => 'Komentari (%d)',
    122 => 'Trackbacks (%d)',
    123 => 'Kompletan HTML je dozvoljen',
    124 => 'Klik za brisanje svih cekiranih stavki',
    125 => 'Da li ste sigurni da zelite da obrisete cekirane stavke?',
    126 => 'Selektuj de-selektuj sve stavke',
    127 => 'Direktan link',
    128 => 'Prijavi se sa OpenID:',
    129 => 'Podesavanja',
    130 => 'Web Servisi'
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => 'Posalji komentar',
    2 => 'Postavke slanja',
    3 => 'Odjava',
    4 => 'Kreirajte korisnicki nalog',
    5 => 'Korisnicko ime',
    6 => 'Da bi poslali komentar, morate biti prijavljeni. Molimo prijavite se. Ako nemate korisnicki nalog mozete ga besplatno kreirati.',
    7 => 'Vas poslednji komentar je bio pre ',
    8 => " sekundi.  Stranica zahteva da prodje najmanje {$_CONF['commentspeedlimit']} sekundi izmedju komentara",
    9 => 'Komentar',
    10 => 'Posalji Izvestaj',
    11 => 'Posalji Komentar',
    12 => 'Molim popunite polje Naslov i Komentar!',
    13 => 'Vase informacije',
    14 => 'Pregled',
    15 => 'Prijavi komentar',
    16 => 'Naslov',
    17 => 'Greska',
    18 => 'Vazno',
    19 => 'Molimo Vas da se pridrzavate teme.',
    20 => 'Molimo Vas da odgovarate na vec objavljene komentare umesto da zapocinjete nove teme.',
    21 => 'Pre nego posaljete komentar, molimo procitajte komentare ostalih korisnika kako bi izbegli ponavljanje.',
    22 => 'Budite jasni kako bi ostalima bilo jasno sta ste zeleli da kazete.',
    23 => 'Vasa email adresa nije javno dostupna.',
    24 => 'Anonimni korisnik',
    25 => 'Sigurno zelite da prijavite ovaj komentar administratoru?',
    26 => '%s prijavljena zloupotreba u sledecem komentaru:',
    27 => 'Prijavi zloupotrebu',
    28 => 'Preview Changes',
    29 => 'Submit Changes',
    30 => 'Edited on',
    31 => 'by',
    32 => 'Editing a Comment',
    33 => 'Editing a Comment Submission',
    34 => 'Preview Submission Changes',
    35 => 'Save Changes to Queue',
    36 => 'Notify me of new replies',
    37 => 'New Comment Reply',
    38 => 'A reply has been made to your comment \'%s\'.',
    39 => 'You may view the comment thread at the following address:',
    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
    41 => 'Hello %s,',
    42 => 'Unsubscribe',
    43 => 'Unsubscribe from reply notifications'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => 'Profil korisnika',
    2 => 'Korisnicko ime',
    3 => 'Puno ime',
    4 => 'Lozinka',
    5 => 'Email adresa',
    6 => 'Web stranica',
    7 => 'Biografija',
    8 => 'PGP kljuc',
    9 => 'Sacuvaj informacije',
    10 => 'Poslednjih 10 komentara od korisnika',
    11 => 'Nema korisnickih komentara',
    12 => 'Korisnicka podesavanja za',
    13 => 'Email beleske',
    14 => 'Ova lozinka je kreirana slucajnim izborom. Preporucujemo da sto pre promenite istu. Da biste promenili lozinku, prijavite se i udjite u Korisnicke postavke',
    15 => "Vas {$_CONF['site_name']} nalog je uspesno kreiran. Da biste ga koristili, morate se prijaviti koristeci vase informacije. Molimo sacuvajte ovu poruku.",
    16 => 'Informacije o vasem nalogu',
    17 => 'Korisnicki nalog nije definisan',
    18 => 'Upisana email adresa nije validna.',
    19 => 'Korisnicko ime ili email adresa koju ste uneli vec postoji u bazi.',
    20 => 'Email adresu koju ste uneli ne mozemo prihvatiti jer nije validna',
    21 => 'Greska',
    22 => "Registracija na {$_CONF['site_name']}!",
    23 => "Kreiranjem korisnickog naloga imate samo prednosti na {$_CONF['site_name']} i mozete koristiti neke funkcije koje obicni korisnici nemogu. Ako nemate nalog, sve sto radite belezi se za anonimnog korisnika. Molimo zapamtitie da vas email <b><i>nikada</i></b> nece biti javno prikazan na ovom sajtu.",
    24 => 'Lozinka ce biti poslata na email adresu koju ste uneli.',
    25 => 'Zaboravili ste lozinku?',
    26 => 'Ukucajte <em>vase</em> korisnicko ime <em>ili</em> email addresu koju ste koristili prilikom registracije i kliknite na Posalji Lozinku. Instrukcije za postavljanje vase nove lozinke saljemo na vas email.',
    27 => 'Registruj se ',
    28 => 'Posalji Lozniku',
    29 => 'forma za odjavu',
    30 => 'forma za prijavu',
    31 => 'Izabrane funkcije zahtevaju da budete prijavljeni',
    32 => 'Potpis',
    33 => 'Nikada ne prikazuj javno',
    34 => 'Ovo je vase pravo ime',
    35 => 'Unesite novu lozinku za promenu',
    36 => 'Pocinje sa http://',
    37 => 'Prikazuje se u vasim komentarima',
    38 => 'Sve o vama! Svi to mogu citati',
    39 => 'Vas javni PGP kljuc',
    40 => 'Kategorija nema ikonu',
    41 => 'Zelite biti moderator',
    42 => 'Format datuma',
    43 => 'Maksimalno tekstova',
    44 => 'Nema blokova',
    45 => 'Postavke prikazivanja za',
    46 => 'Delovi za izvrsavanje za',
    47 => 'Konfiguracija tekstova za',
    48 => 'Kategorije',
    49 => 'Nema ikone u tekstu',
    50 => 'Deselektuje ovo ako niste zainteresovani',
    51 => 'Samo novi tekstovi',
    52 => 'Podrazumevani',
    53 => 'Primi nove vesti svaku noc',
    54 => 'Oznaci blokove za naslove i autore koje ne zelis da vidis.',
    55 => 'Ako ovo ostavite kako jeste, to znaci da hocete obicne selekcije blokova. Ako pocnete birati blokove, zapamtite da postavite sve one koje zelite jer ce obicna postavka biti zanemarena. Obicne postavke su boldirane.',
    56 => 'Autori',
    57 => 'Nacin prikazivanja',
    58 => 'Sortiraj po',
    59 => 'Maksimalno komentara',
    60 => 'Kako zelite da se vasi komentari prikazuju?',
    61 => 'Noviji ili najstariji prvo?',
    62 => 'Podrazumevano je 100',
    63 => "Vasa lozinka vam je poslata putem emaila i trebali biste je primiti svakog trenutka. Molimo pratite instrukcije koje ste dobili u poruci i zahvaljujemo vam za prijavu na {$_CONF['site_name']}",
    64 => 'Postavke komentara za',
    65 => 'Pokusajte ponoviti prijavu',
    66 => "Verovatno ste pogresno uneli korisnicko ime ili lozinku. Pokusajte se ponovo prijaviti. Jeste li <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">novi korisnik</a>?",
    67 => 'Clan od',
    68 => 'Pamti me',
    69 => 'Koliko dugo zelite biti prijavljeni?',
    70 => "Postavi izgled sajta {$_CONF['site_name']}",
    71 => "Jedna od velikih prednosti {$_CONF['site_name']} je ta sto mozete promeniti izgled sajta po vasoj volji. Da biste to mogli uciniti morate se prvo <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">registrovati</a> na {$_CONF['site_name']}. Ako ste vec clan, koristite vase podatke i prijavite se!",
    72 => 'Kategorija',
    73 => 'Jezik',
    74 => 'Promeni izgled sajta!',
    75 => 'Email-ovani tekstovi za',
    76 => 'Ako selektujete kategoriju iz liste ispod, primit cete svaki novi tekst vezan za tu kategoriju na kraju svakog dana. Izaberi jedino onu kategoriju koja te zaista zanima!',
    77 => 'Fotografija',
    78 => 'Dodaj vlastitu fotografiju!',
    79 => 'Oznaci ovde za brisanje fotografije',
    80 => 'Prijava',
    81 => 'Salji email',
    82 => 'Poslednjih 10 tekstova od korisnika',
    83 => 'Statistika slanja tekstova i komentara za korisnika',
    84 => 'Ukupan broj tekstova:',
    85 => 'Ukupan broj komentara:',
    86 => 'Pronadji sve tekstove od',
    87 => 'Vase korisnicko ime',
    88 => "Neko (verovatno vi) je zatrazio novu lozinku za vas korisnicki nalog \"%s\" na {$_CONF['site_name']}, <{$_CONF['site_url']}>.\n\nAko ste to zaista hteli molimo kliknite na ovaj link za potvrdu:\n\n",
    89 => "Ako ne zelite to napraviti, jednostavno ignorisite poruku (lozinka ce ostati nepromenjena).\n\n",
    90 => 'Mozete ukucati novu lozinku za vas nalog ispod. Molimo zabelezite da ja vasa stara lozinka i dalje validna dok neprimite novu.',
    91 => 'Postavi novu lozinku',
    92 => 'Unesi novu lozinku',
    93 => 'Vas poslednji zahtev za novom lozinkom je bio pre %d sekundi. Ovaj sajt zahteva barem %d sekundi izmedju zahteva za slanje lozinke.',
    94 => 'Obrisi korisnicki nalog "%s"',
    95 => 'Pritisni "Obrisi korisnicki nalog" dugme ispod da biste obrisali vas nalog iz nase baze podataka. Molimo zapamtite da bilo koja vest ili komentar poslat sa vase strane pod ovim korisnickim racunom <strong>nece</strong> biti izbrisan, vec ce se prikazivati kao vlasnistvo korisnika "Anonimus".',
    96 => 'Obrisi korisnicki nalog',
    97 => 'Potvrdi brisanje korisnickog naloga',
    98 => 'Da li ste sigurni da zelite obrisati nalog? Ako to zelite necete vise moci koristiti ovaj sajt kako ste pre mogli (ukoliko ne kreirate novi nalog). Ako ste sigurni da to zelite uraditi pritisnite "Obrisi korisnicki nalog".',
    99 => 'Opcije privatnosti za ',
    100 => 'Email od administratora',
    101 => 'Dozvoli mailove od webmastera',
    102 => 'Email od korisnika',
    103 => 'Dozvoli primanje emailova od korisnika',
    104 => 'Prikazi online status',
    105 => 'Prikazi ko je online u bloku',
    106 => 'Lokacija',
    107 => 'Prikazi u javnom profilu',
    108 => 'Potvrdi novu lozinku',
    109 => 'Unesi novu lozinu ponovo',
    110 => 'Trenutna lozinka',
    111 => 'Molimo unesite trenutnu lozinku',
    112 => 'Prekoracli ste dozvoljen broj pokusaja za prijavu. Molimo pokusajte kasnije.',
    113 => 'Pokusaj prijave neuspesan',
    114 => 'Nalog Blokiran',
    115 => 'Vas nalog je blokiran, niste u mogucnosti da se prijavite. Molimo kontaktirajte Administratora.',
    116 => 'Nalog je u procesu aktivacije',
    117 => 'Vas nalog je trenutno u aktivacionom procesu i ceka odobrenje od strane Administratora. Necete biti u mogucnosti da se prijavite sve dok vas nalog nebude odobren.',
    118 => "Vas {$_CONF['site_name']} nalog je aktiviran od strane administratora. Sada se mozete prijaviti na sajt koriscenjem vaseg korisnickog imena (<username>) i lozinke koju smo vam ranije poslali.",
    119 => 'Ako ste zaboravili lozinku, mozete zatraziti novu na ovoj adresi:',
    120 => 'Nalog aktiviran',
    121 => 'Opcije',
    122 => 'Proces registracije novih korisnika je trenutno blokiran',
    123 => "Da li ste <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">novi korisnik</a>?",
    124 => 'Potvrdi Email',
    125 => 'Morate uneti identicnu email adresu u oba polja!',
    126 => 'Molimo ponovite zbog potvrde',
    127 => 'Kako bi promenili bilo koje od ovih podesavanja, morate uneti vasu trenutnu lozinku.',
    128 => 'Vase Ime',
    129 => 'Lozinka i Email',
    130 => 'O Vama',
    131 => 'Daily Digest Options',
    132 => 'Daily Digest Feature',
    133 => 'Prikaz Komentara',
    134 => 'Opcije Komentara',
    135 => '<li>Podrazumevani mod za komentare ce sada biti prikazan</li><li>Podrazumevani nacin za sortiranje komentara</li><li>Postavite maksimalan broj komentara za prikaz - podrazumeva se 100</li>',
    136 => 'Zanemari Tekstove i Autore',
    137 => 'Filtriraj Sadrzaj Teksta',
    138 => 'Ostala podesavanja',
    139 => 'Izgled i Jezik',
    140 => '<li>Ako je cekirano Kategorija nema ikonu, ikonica nece biti prikazivana kod pregleda kategorija.</li><li>Ako je cekirana opcija Nema blokova bice prikazan samo Administratorski, Korisnicki Meni i Kategorije<li>Postavi maksimalan broj tekstova za prikaz po strani</li><li>Postavi svoju temu i zelejni format datuma</li>',
    141 => 'Podesavanje Privatnosti',
    142 => 'Podrazumevano podesavanje je da korisnici i administratori mogu da posalju email clanovima sajta i da mogu da prikazu vas online status. De-cekirajte ove opcije kako bi zastitili vasu privatnost.',
    143 => 'Filtriraj Blok Sadrzaj',
    144 => 'Prikazi i sakrij blokove',
    145 => 'Vas Javni Profil',
    146 => 'Lozinka i email',
    147 => 'Izmeniti vasu lozinku, email, autologin opciju. Morate uneti identicnu lozinku ili email dva puta zbog potvrde.',
    148 => 'Korisnicke Informacije',
    149 => 'Izmenite vase korisnicke informacije koje ce biti prikazane drugim korisnicima.<li>Potpis ce biti dodat na svaki komentar ili post na forumu koji objavite</li><li>Biografija predstavlja kratke informacije o Vama koje zelite da podelite</li><li>Podelite Vas PGP Kljuc</li>',
    150 => 'Upozorenje: Javascript se preporucuje zbog poboljsanih performansi.',
    156 => 'Obrisi Nalog',
    157 => 'Obirsi Opciju',
    158 => 'Vremenska Zona',
    159 => 'Ovaj email je automatski generisan. Molimo nemojte odgovarati na njega.',
    160 => '(max. %d x %d pixels, %d bytes; %s)',
    161 => 'will be scaled down',
    162 => 'will not be scaled'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Pregled',
    'pe_namepass' => 'Korisnicko Ime i Lozinka',
    'pe_userinfo' => 'O Vama',
    'pe_layout' => 'Prikaz i Jezik',
    'pe_content' => 'Sadrzaj',
    'pe_privacy' => 'Privatnost'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => 'Nema tekstova za prikaz.',
    2 => 'Nema novih tekstova za prikaz. Mozda nema tekstova',
    3 => ' u kategoriji %s',
    4 => 'Danasnji bitni tekstovi',
    5 => 'Sledeci',
    6 => 'Prethodni',
    7 => 'Prvi',
    8 => 'Poslednji'
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => 'Prilikom slanja dogodila se greska. Molimo pokusajte ponovo.',
    2 => 'Poruka je uspesno poslata.',
    3 => 'Molimo koristite validnu email adresu u Primalac polju.',
    4 => 'Molimo popunite polja: Vase ime, Primalac, Naziv maila i Poruku',
    5 => 'Greska: Korisnik ne postoji.',
    6 => 'Doslo je do greske.',
    7 => 'Korisnicki profil za',
    8 => 'Korisnicko ime',
    9 => 'Korisnicki URL',
    10 => 'Salji email',
    11 => 'Vase ime:',
    12 => 'Primalac:',
    13 => 'Naziv maila:',
    14 => 'Poruka:',
    15 => 'HTML kod nece biti prikazan.',
    16 => 'Posalji poruku',
    17 => 'Posalji tekst e-mailom',
    18 => 'Saljete (kome)',
    19 => 'Na email adresu',
    20 => 'Od',
    21 => 'Vas email',
    22 => 'Potrebno je sve popuniti',
    23 => "Ovaj email vam je poslat od %s sa %s zato jer korisnik misli da ce vas zanimati tekst sa web stranice {$_CONF['site_url']}.  Ovo NIJE SPAM, i vase email adrese nisu sacuvane i nece se koristiti za dalju upotrebu.",
    24 => 'Komentar za ovaj tekst na',
    25 => 'Morate biti prijavljeni da bi mogli koristiti ovu postavku.',
    26 => 'Ovaj formular vam dozvoljava slanje emailova odredjenim korisnicima. Potrebno je popuniti sve podatke.',
    27 => 'Kratka poruka',
    28 => '%s pise: ',
    29 => "Ovo su dnevni tekstovi sa {$_CONF['site_name']} za ",
    30 => ' Dnevni tekstovi za ',
    31 => 'Naziv',
    32 => 'Datum',
    33 => 'Procitaj kompletan tekst na',
    34 => 'Kraj poruke',
    35 => 'Zao mi je, korisnik ne dozvoljava prijem poruka.',
    36 => 'Copy:',
    37 => 'Send me a copy of this email',
    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => 'Napredna pretraga',
    2 => 'Kljucne reci',
    3 => 'Kategorija',
    4 => 'Sve',
    5 => 'Vrsta',
    6 => 'Tekstovi',
    7 => 'Komentari',
    8 => 'Autori',
    9 => 'Svi',
    10 => 'Pretrazivanje',
    11 => 'Rezultati pretrazivanja',
    12 => 'pogodaka',
    13 => 'Rezultati pretrazivanja: Nema rezultata',
    14 => 'Nema rezultata koji odgovaraju vasem upitu',
    15 => 'Molimo pokusajte ponovo.',
    16 => 'Naslov',
    17 => 'Datum',
    18 => 'Autor',
    19 => "Pretrazite bazu podataka web stranice {$_CONF['site_name']} nase trenutne i arhivirane tekstove",
    20 => 'Datum',
    21 => 'do',
    22 => '(Format datuma GGGG-MM-DD)',
    23 => 'Pregleda',
    24 => 'Pronadjeno %d rezultata',
    25 => 'Trazeno za',
    26 => 'upita ',
    27 => 'sekundi',
    28 => 'Nema odgovarajucih tekstova ili komentara za upit koji ste zadali',
    29 => 'Rezultati tekstova i komentara',
    30 => '',
    31 => 'Ovaj plug-in nije nista pronasao',
    32 => '',
    33 => 'URL',
    34 => 'Lokacija',
    35 => 'Celi dan',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => 'Vas upit mora sadrzati vise od 3 znaka.',
    42 => 'Molimo koristite format datuma GGGG-MM-DD (godina-mesec-dan).',
    43 => 'tacan izraz',
    44 => 'sve reci',
    45 => 'bilo koja od ovih reci',
    46 => 'Sledeci',
    47 => 'Prethodni',
    48 => 'Autor',
    49 => 'Datum',
    50 => 'Pregleda',
    51 => '',
    52 => 'Lokacija',
    53 => 'Rezultati za tekstove',
    54 => 'Rezultati za komentare',
    55 => 'izraz(e)',
    56 => 'I',
    57 => 'ILI',
    58 => 'Jos rezultata &gt;&gt;',
    59 => 'Rezultati',
    60 => 'po strani',
    61 => 'Napredna pretraga',
    62 => '#',
    63 => 'Description',
    64 => 'Showing %1$d - %2$d of %3$d results',
    65 => 'Story',
    66 => 'Comment',
    67 => 'Show %d Results',
    68 => 'Sort By',
    69 => 'Titles Only',
    70 => 'Not available ...'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => 'Statistika web stranice',
    2 => 'Ukupno poseta na sve strane',
    3 => 'Tekstova(Komentara) na stranama',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Najcitaniji tekstovi',
    8 => 'Naslov teksta',
    9 => 'Pregleda',
    10 => 'Na stranama nema niti jednog teksta ili ni jedan tekst nije procitan.',
    11 => 'Tekstovi sa najvecim brojem komentara',
    12 => 'Komentari',
    13 => 'Na stranicama nema niti jednog poslatog teksta ili teksta na kojem ima komentara.',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => 'Tekstovi koji su najcesce slani emailom',
    23 => 'Emailovi',
    24 => 'Niko nije poslao tekst emailom sa ovih stranica.',
    25 => 'Prvih 10 Trackback Komentarisanih Tekstova',
    26 => 'Trackback komentari nisu pronadjeni.',
    27 => 'Broj aktivnih korisnika',
    28 => '',
    29 => '',
    30 => 'Pregleda',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => 'Linkovi u tekstu',
    2 => 'Posalji tekst emailom',
    3 => 'Vezija za stampu',
    4 => 'Opcije teksta',
    5 => '',
    6 => 'Prijavi se za \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => 'Da posaljete tekst %s morate biti ulogovani.',
    2 => 'Prijava',
    3 => 'Novi korisnik',
    4 => '',
    5 => '',
    6 => 'Posaljite tekst',
    7 => 'Prijava je neophodna',
    8 => 'Potvrdi',
    9 => 'Kada saljete informacije za koriscenje na ovom sajtu molimo vas da pratite sledece savete...<ul><li>Morate popuniti sva polja<li>Posaljite kompletne i tacne informacije<li>Dva puta proverite ove URL-ove</li></ul>',
    10 => 'Naziv',
    11 => '',
    12 => 'Pocinje dana',
    13 => 'Zavrsava dana',
    14 => 'Lokacija',
    15 => 'Opis',
    16 => '',
    17 => '',
    18 => '',
    19 => 'Molimo procitajte tekst koji sledi',
    20 => '',
    21 => '',
    22 => 'Greska: Polja nisu popunjena',
    23 => 'Molimo popunite sva polja. Sva polja su obavezna.',
    24 => 'Tekst sacuvan',
    25 => 'Vas %s tekst je uspesno sacuvan',
    26 => 'Spam Zastita',
    27 => 'Korisnicko ime',
    28 => 'Kategorija',
    29 => 'Tekst',
    30 => 'Poslali ste tekst pre',
    31 => " sekundi. Ovaj sajt zahteva barem {$_CONF['speedlimit']} sekundi razmaka izmedju slanja tekstova",
    32 => 'Pogledaj',
    33 => 'Pogledaj kako tekst izgleda',
    34 => 'Odjava',
    35 => 'HTML kodovi nisu dozvoljeni',
    36 => 'Nacin slanja',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Adresa 1',
    45 => 'Adresa 2',
    46 => 'Grad',
    47 => 'Drzava',
    48 => 'Zip kod',
    49 => '',
    50 => '',
    51 => 'Lokacija',
    52 => 'Obrisi',
    53 => 'Kreiraj nalog',
    54 => 'Uvodni Tekst',
    55 => 'Kompletan Tekst'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => 'Autorizacija neophodna',
    2 => 'Pristup Zabranjen! Netacne informacije u prijavi',
    3 => 'Neispravna korisnicka lozinka',
    4 => 'Korisnicko ime:',
    5 => 'Lozinka:',
    6 => 'Svaki pokusaj pristupa administratorskim delovima se loguje i proverava.<br' . XHTML . '>Ova stranica je iskljucivo namenjena odredjenim autorizovanim clanovima.',
    7 => 'prijava'
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => 'Neispravna Administratorska prava',
    2 => 'Nemate potrebna prava za izmenu Bloka.',
    3 => 'Blok Editor',
    4 => 'Doslo je do problema prilikom citanja ovog feed-a (pogledaj error.log za vise detalja).',
    5 => '',
    6 => '',
    7 => 'Svi',
    8 => 'Sigurnosni nivo Bloka',
    9 => 'Redosled Bloka',
    10 => '',
    11 => 'Portal Blok',
    12 => 'Normalni Blok',
    13 => 'Opcije Portal Bloka',
    14 => 'RSS URL',
    15 => 'Poslednji RSS Update',
    16 => 'Opcije Normalnog Bloka',
    17 => 'Sadrzaj Bloka',
    18 => 'Molimo popunite Naziv Bloka i polja sa sadrzajem',
    19 => 'Blok Menadzer',
    20 => '',
    21 => 'Specijalni nivo Bloka',
    22 => '',
    23 => 'Zadatak Bloka',
    24 => '',
    25 => 'Da biste modifikovali Blok ili ga izbrisali, kliknite dole na zeljeni link. Da biste napravili novi Blok, kliknite na "Kreiraj Novi" iznad.',
    26 => 'Izgled Bloka',
    27 => 'PHP Blok',
    28 => 'Opcije PHP Bloka',
    29 => 'Funkcije Bloka',
    30 => 'Ako zelite da imate jedan svoj Blok koristite PHP kod, upisite ime funkcije iznad. Ime vase funkcije mora poceti sa prefiksom "phpblock_" (npr. phpblock_getweather). Ako nemate ovaj prefiks, vasa funkcija NECE biti pozvana. Ovo radimo zbog toga da bismo zadrzali ljude koji su mozda uspeli upasti u vas proces instalacije menjajuci neke funkcije i pozivajuci se na njih i koje mogu biti kriticne za vas sistem. Budite sigurni da negde ne ostavite prazne zagrade "()" posle vaseg imena funkcije. Na kraju, preporucljivo je da smestite sve svoje PHP kodove Blokova u /path/to/geeklog/system/lib-custom.php. To ce omoguciti kodu da ostane sa vama i na svom mestu cak i kada nadogradite verziju Geeklog-a.',
    31 => 'Greska u PHP Bloku. Funkcija, %s, ne postoji.',
    32 => 'Greska, nedostaje/u polje/a',
    33 => 'Morate navesti URL za pristup RSS fajlu za portal blok',
    34 => 'Morate navesti naziv i funkciju za PHP blokove',
    35 => 'Morate upisati naziv i sadrzaj za normalne blokove',
    36 => 'Morate upisati sadrzaj za izgled blokova',
    37 => 'Lose ime funkcije PHP bloka',
    38 => 'Funkcije za PHP Blokove moraju imati prefiks \'phpblock_\' (npr. phpblock_getweather). Prefiks \'phpblock_\' je potreban iz sigurnosnih razloga da bi se zastitio deo koda za izvrsavanje.',
    39 => 'Strana',
    40 => 'Levo',
    41 => 'Desno',
    42 => 'Morate navesti Ime Bloka i Namenu Bloka za obicne Geeklog blokove.',
    43 => 'Jedino na pocetnoj strani(Home/index)',
    44 => '',
    45 => "Pokusavate pristupati bloku za koji nemate prava pristupa. Ovaj pokusaj pristupa je zabelezen. Molimo <a href=\"{$_CONF['site_admin_url']}/block.php\">vratite se nazad</a>.",
    46 => 'Novi Blok',
    47 => '',
    48 => 'Naziv Bloka',
    49 => ' (nema razmaka i mora biti jedinstven)',
    50 => '',
    51 => 'ukljucujuci http://',
    52 => 'Ako ostavite ovo prazno help ikona za ovaj blok se nece prikazati',
    53 => 'Omoguci',
    54 => 'sacuvaj',
    55 => 'odustani',
    56 => 'obrisi',
    57 => 'Pomeri Blok dole',
    58 => 'Pomeri Blok gore',
    59 => 'Prebaci Blok na desnu stranu',
    60 => 'Prebaci Blok na levu stranu',
    61 => 'Nema Naziva',
    62 => 'Limit Tekstova',
    63 => 'Los Naziv',
    64 => 'Vas Naziv nesme biti prazan i nesme sadrzati HTML!',
    65 => 'Redosled',
    66 => 'Autotagovi',
    67 => 'Klikni da omogucis autotagove',
    68 => 'Feed za portal blog je previse dugacak za prikaz. Molimo podesite maximalan broj tekstova za import u samoj blok konfiguraciji ili u globalnim Geeklog Podesavanjima.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => 'Prethodni tekst',
    2 => 'Sledeci tekst',
    3 => 'Rezim',
    4 => 'Postavke slanja',
    5 => 'Izmena teksta',
    6 => 'Nema teksta u sistemu.',
    7 => 'Autor',
    8 => 'sacuvaj',
    9 => 'pregled',
    10 => 'otkazi',
    11 => 'obrisi',
    12 => 'ID',
    13 => '',
    14 => '',
    15 => 'Datum',
    16 => 'Uvodni tekst',
    17 => 'Kompletan tekst',
    18 => 'Pregleda',
    19 => 'Komentari',
    20 => 'Ping',
    21 => 'Posalji Ping',
    22 => 'Pregled tekstova',
    23 => 'Da biste izmenili ili obrisali neki tekst, kliknite na ikonicu u "Izmeni" polju. Da biste pregledali tekst, kliknite na naziv teksta koji zelite pregledati. Ako zelite da napisete novi tekst izaberite opciju "Kreiraj novi" koja se nalazi iznad.',
    24 => 'ID koji ste izabrali za ovaj tekst vec je iskoriscen. Molimo promenite ID.',
    25 => 'Greska prilikom cuvanja teksta',
    26 => 'Pregled teksta',
    27 => 'Ako koristite [unscaledX] umesto [imageX], slika ce biti dodata sa njenim orginalnim dimenzijama.',
    28 => '<p><b>PREGLED</b>: Pregled teksta sa slikama je najbolji u slucaju kada tekst sacuvate koriscenjem draft opcije, mnogo bolji nego ako koristite samo dugme za pregled.  Predlazemo da dugme za pregled koristite samo kada tekst ne sadrzi slike.',
    29 => 'Trackbacks',
    30 => 'Greske prilikom dodavanja fajla',
    31 => 'Molimo popunite polja Naziv i Uvodni tekst',
    32 => 'Uoblici',
    33 => 'Moze biti samo jedan uobliceni tekst',
    34 => 'Draft',
    35 => 'Da',
    36 => 'Ne',
    37 => 'Vise od',
    38 => 'Vise iz',
    39 => 'Emailovi',
    40 => '',
    41 => "Pokusavate pristupati tekstu za koji nemate prava pristupa. Ovaj pokusaj pristupa je zabelezen. Mozete pogledati tekst u delu samo citanje ispod. Molimo <a href=\"{$_CONF['site_admin_url']}/story.php\">vratite se nazad</a> kada zavrsite.",
    42 => "Pokusavate pristupiti tekstu za koji nemate prava pristupa. Ovaj pokusaj pristupa je zabelezen. Molimo <a href=\"{$_CONF['site_admin_url']}/story.php\">vratite se nazad</a>.",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>NAPOMENA:</b> ako podesite ovaj datum da se prikaze u buducnosti, ovaj tekst nece biti objavljen sve do tog datuma. To takodje znaci da ovaj tekst nece biti ukljucen u vas RSS headline feed i isti ce biti ignorisan na statickim i stranama pretrage.',
    47 => 'Slike',
    48 => 'slika',
    49 => 'desno',
    50 => 'levo',
    51 => '<p>Da biste dodali jednu od vasih slika odredjenom tekstu morate ubaciti specijalno formirani tekst. Taj tekst izgleda ovako [imageX], [imageX_right] ili [imageX_left] gde je X broj slike koju ste ubacili. NAPOMENA: Morate koristiti sliku koju ste vec odabrali za taj tekst. Ako to ne ucinite necete moci sacuvati tekst.<BR><P><B>PREGLED</B>: Pregled teksta sa slikama je najbolji u slucaju kada tekst sacuvate koriscenjem draft opcije, mnogo bolji nego ako koristite samo dugme za pregled.  Predlazemo da dugme za pregled koristite samo kada tekst ne sadrzi slike.</p>',
    52 => '',
    53 => 'nije koriscena. Morate ukljuciti ovu sliku u uvodni ili kompletan tekst pre nego sacuvate izmene',
    54 => 'Ukljucene slike nisu koriscene',
    55 => 'Sledece greske su se pojavile prilikom pokusaja cuvanja teksta.  Molimo ispravite ove greske pre cuvanja',
    56 => 'Prikazi ikonu kategorije',
    57 => 'Pogledaj ne-skaliranu sliku',
    58 => 'Tekst Menadzer',
    59 => 'Opcija',
    60 => '',
    61 => 'Automatsko Arhiviranje',
    62 => 'Automatsko Brisanje',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => 'Prosiri Polje Za Izmenu',
    68 => 'Smanji Polje Za Izmenu',
    69 => 'Datum Objavljivanja Teksta',
    70 => 'Izbor Toolbar-a',
    71 => 'Osnovni Toolbar',
    72 => 'Jednostavan Toolbar',
    73 => 'Napredni Toolbar',
    74 => 'Napredni II Toolbar',
    75 => 'Full Uoblicen',
    76 => 'Opcije Objavljivanja',
    77 => 'Javascript mora biti omogucen za koriscenje Naprednog Editora. Opcija moze biti onemogucena u config.php fajlu',
    78 => 'Klikni <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">ovde</a> za koriscenje podrazumevanog editora',
    79 => 'Pregled',
    80 => 'Editor',
    81 => 'Opcije Objavljivanja',
    82 => 'Slike',
    83 => 'Opcije Arhiviranja',
    84 => 'Dozvole',
    85 => 'Prikazi Sve',
    86 => 'Napredni Editor',
    87 => 'Tekst Statistka',
    88 => 'Wiki-stil format',
    89 => 'Meta Description',
    90 => 'Meta Keywords',
    91 => 'You can always hit "Preview" to extend the expiry time.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => 'Menadzer Kategorija',
    2 => 'Kategorija ID',
    3 => 'Naziv Kategorije',
    4 => 'Slika Kategorije',
    5 => '(bez razmaka)',
    6 => 'Brisanje kategorije sa sobom povlaci i brisanje svih tekstova koji se nalaze u njoj!',
    7 => 'Molimo popunite polja Kategorija ID i Naziv Kategorije',
    8 => 'Menadzer Kategorija',
    9 => 'Da izmenite ili obrisete kategoriju kliknite na istu. Da kreirate novu kategoriju kliknite na "Kreiraj Novi" dugme iznad. Mozete podesiti i prava pristupa za svaku kategoriju ponaosob. Znak(*) oznacava podrazumevanu kategoriju.',
    10 => 'Sortirano po',
    11 => 'Tekstova po strani',
    12 => 'Pristup odbijen.',
    13 => "Pokusavate da pristupite kategorij za koju nemate prava pristupa. Ovaj pokusaj je zabelezen. Molimo<a href=\"{$_CONF['site_admin_url']}/topic.php\">vratite se nazad na administraciju</a>.",
    14 => 'Metode sortiranja',
    15 => 'leksikografski',
    16 => 'podrazumevano je',
    17 => 'Nova kategorija',
    18 => 'Admin Home',
    19 => 'sacuvaj',
    20 => 'otkazi',
    21 => 'obrisi',
    22 => 'Podrazumevano',
    23 => 'neka ova kategorija bude podrazumevana kategorija za tekstove koje salju korisnici',
    24 => '(*)',
    25 => 'Arhiviraj Kategoriju',
    26 => 'neka ova kategorija bude podrazumevana za arhiviranje tekstova. Samo jedna kategorija je dozvoljena za ovo.',
    27 => 'Ili Uploaduj Ikonu Kategorije',
    28 => 'Makismalna velicina',
    29 => 'Greska Prilkom Uplod-a',
    30 => 'Stories in Topic'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => 'Korisnicko uredjivanje',
    2 => 'Korisnicki ID',
    3 => 'Korisnicko Ime',
    4 => 'Ime i Prezime',
    5 => 'Lozinka',
    6 => 'Sigurnosni Nivo',
    7 => 'Email Adresa',
    8 => 'Web Stranica',
    9 => '(ne koristite razmake)',
    10 => 'Molimo popunite polja Korisnicko ime i Email adresa',
    11 => 'Uredjivanje korisnika',
    12 => 'Da izmenite ili obrisete korisnika, kliknite na odgovarajucu ikonicu u "Izmeni" polju. Da kreirate novog korisnika kliknite na dugme "Kreiraj Novi" iznad. Mozete i koristiti jednostavnu pretragu po delovima korisnickog imena, email adrese ili punog imena korisnika.',
    13 => 'Sigurnosni nivo',
    14 => 'Datum registracije',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => 'sacuvaj',
    21 => 'Korisnicko ime koje pokusavate da sacuvate vec postoji.',
    22 => 'Greska',
    23 => 'Masovno Dodavanje',
    24 => 'Masovno Dodavanje Korisnika',
    25 => 'Geeklog Vam omogucava masovno dodavanje korisnika. Fajl koji importujete mora koristiti tab-delimited tekstualni fajl i mora imati sledeca polja bas u redu koji je naveden: Ime i prezime, Korisnicko ime, email adresa. Svaki korisnik kojeg dodate na email adresu ce dobiti slucajno generisanu lozinku. U tekstualnom fajlu mora biti jedan korisnik u jednoj liniji teksta. U koliko nebudete pratili instrukcije koje su prethodno navedene doci ce do problema i vrlo verovatno da ce biti potrebna manualna ispravka. Zato dobro proverite podatke!',
    26 => '',
    27 => '',
    28 => 'Oznacite ovde da bi obrisali sliku.',
    29 => 'Putanja',
    30 => 'Importuj',
    31 => 'Novi korisnici',
    32 => 'Procesiranje zavrseno. Ukupno %d dodato i ukupno %d gresaka',
    33 => 'posalji',
    34 => 'Greska: Morate izabrati fajl za upload.',
    35 => 'Poslednji put prijavljen',
    36 => '(nikada)',
    37 => 'UID',
    38 => 'Menadzer Korisnickih Grupa',
    39 => 'Lozinka (ponovo)',
    40 => 'Datum Registracije',
    41 => 'Poslednje Prijavljivanje',
    42 => 'Banovan',
    43 => 'Ceka Aktivaciju',
    44 => 'Ceka Autorizaciju',
    45 => 'Aktivan',
    46 => 'Korisnicki Status',
    47 => 'Izmeni',
    48 => 'Prikazi Admin Grupe',
    49 => 'Admin Grupa',
    50 => 'Cekiraj da dozvolis filtriranje ove grupe kao Admin Grupe Koriscenja',
    51 => 'Online Dana',
    52 => '<br' . XHTML . '>Napomena: "Online Dana" je broj dana izmedju prve registracije i poslednje prijave.',
    53 => 'registrovan',
    54 => 'Masovno Brisanje',
    55 => 'Ovo jedino radi ako je <code>$_CONF[\'lastlogin\'] = true;</code> u vasem config.php fajlu',
    56 => 'Molimo izaberite tip korisnika koji zelite da obrisete i onda pritisnite dugme "Azuriraj Listu". Onda, decekirajte one koje ne zelite da obrisete iz te liste i kliknite na "Brisanje". Zapamtite da cete obirsati samo one korisnike koje vidite u slucaju da se lista prostire na vise strana.',
    57 => 'Phantom korisnici',
    58 => 'Kratkorocni korisnici',
    59 => 'Stari Korisnici',
    60 => 'Korisnici koji su registrovani pre vise od ',
    61 => ' meseci ali se nikad nisu prijavili na sajt.',
    62 => 'Korisnici koji su registrovani pre vise od ',
    63 => ' meseci, onda se ulogovali u roku od 24 sat, ali nakon toga nikada nisu pristupili sajtu',
    64 => 'Normalni korisnici, koji jednostavno ne posecuju vas sajt vec ',
    65 => ' meseci.',
    66 => 'Azuriraj Listu',
    67 => 'Meseci od registracije',
    68 => 'Online Sati',
    69 => 'Offline Meseci',
    70 => 'nemoze biti obrisan',
    71 => 'uspesno obrisan',
    72 => 'Nema korisnika slektovanih za brisanje',
    73 => 'Da li ste sigurni da zelite da obrisete SVE selektovane korisnike?',
    74 => 'Poslednji korsicnici',
    75 => 'Korisnici koji su se registrovali u poslednjih ',
    76 => ' meseci',
    77 => 'Posalji Email za prijavu na sajt selektovanim korisnicima',
    78 => 'Posalji podsetnik',
    79 => 'Nema selektovanih korisnika za podsetnik',
    80 => 'Podsetnici uspesno poslati',
    81 => 'Podsetnik za verifikaciju naloga na %s',
    82 => "Vas nalog na {$_CONF['site_name']} nije doziveo pristup jos od %s i bice obrisan ako se preko njega ne pristupi u roku od 30 dana.",
    83 => "Vas nalog na {$_CONF['site_name']} nije koriscen od dana kada je kreiran i bice obrisan uskoro ako se preko njega ne pristupi.",
    84 => "Vase korisnicko ime je: %s  za nas sajt: {$_CONF['site_url']}",
    85 => 'Ako ste zaboravili lozinku korsitite sledeci link: %s',
    86 => 'Podsetnici',
    87 => 'Reminders'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => 'Prihvati',
    2 => 'Obrisi',
    3 => 'Azuriraj',
    4 => 'Profil',
    10 => 'Naziv',
    11 => 'Pocinje dana',
    12 => 'URL',
    13 => 'Kategorija',
    14 => 'Datum',
    15 => 'Kategorija',
    16 => 'Korisnicko Ime',
    17 => 'Ime I Prezime',
    18 => 'Email',
    34 => 'Komande i Kontrola',
    35 => 'Zahtev za postavljanje teksta',
    36 => 'Parent or Comment',
    37 => '',
    38 => 'Potvrdi',
    39 => 'Trenutno nema tekstova (korisnickih doprinosa) za administraciju',
    40 => 'Korisnicki Tekstovi (Poslati Materijali)',
    41 => 'Comment Submissions',
    42 => 'User Name',
    43 => 'Auto-publish Comments?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => "{$_CONF['site_name']} Mail Menadzer",
    2 => 'Od',
    3 => 'Vrati odgovor na',
    4 => 'Naslov',
    5 => 'Tekst Prouke',
    6 => 'Salji:',
    7 => 'Svi korisnici',
    8 => 'Admin',
    9 => 'Opcije',
    10 => 'HTML',
    11 => 'Hitna poruka!',
    12 => 'Posalji',
    13 => 'Ponisti',
    14 => 'Ignorisi postavke korisnika',
    15 => 'Greska pri slanju: ',
    16 => 'Uspesno poslate poruke za: ',
    17 => "<a href={$_CONF['site_admin_url']}/mail.php>Posalji novu poruku</a>",
    18 => 'Za',
    19 => 'NAPOMENA: ako zelite da posaljete poruku svim clanovima sajta, selektujte Logged-in korisnicku grupu iz liste ispod.',
    20 => "Uspesno poslato <successcount> poruka i bezuspesno poslato <failcount> poruka.  Ako su Vam potrebni, detalji za svaki pokusaj su ovde.  U suprotnom mozete <a href=\"{$_CONF['site_admin_url']}/mail.php\">poslati novu poruku</a> ili se <a href=\"{$_CONF['site_admin_url']}/moderation.php\">vratiti na dministraciju</a>.",
    21 => 'Greske',
    22 => 'Uspesnost',
    23 => 'Nema gresaka',
    24 => 'Nema uspesnosti',
    25 => '-- Odaberite grupu --',
    26 => 'Molimo popunite sva polja u formi i izaberite korisnicku grupu iz liste.'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => 'Instaliranje pluginova moze izazvati ostecena kod vase Geeklog instalacije i teoretski kod vaseg sistema. Vazno je napomenuti da treba da instalirate samo one pluginove koje ste preuzeli sa <a href="http://www.geeklog.net">Geeklog Zvanicne Strane</a> zato sto mi detaljno testiramo sve poslate pluginove na gotovo svim operativnim sistemima. Treba da znate da ce proces instalacije plugina traziti izvrsenje nekoliko komandi fajlsistema sto moze dovesti do sigurnosnih problema ako koristite pluginove sa nekih drugih sajtova.  Cak i sa ovim upozorenjem koje ste dobili, mi nemozemo garantovati uspeh niti jedne instalacije niti smo odgovorni za eventualnu stetu koja je prouzrokovana instalacijom Geeklog plugina.  Drugim recima, instalirate na sopstvenu odgovornost.  Radi opreza, uputstva kako da manuelno instalirate plugin nalaze se u samom plugin paketu.',
    2 => 'Plugin Instalacioni Disclaimer',
    3 => 'Plugin Instalaciona Forma',
    4 => 'Plugin Fajl',
    5 => 'Plugin Menadzer',
    6 => 'Upozorenje: Plugin Je Vec Instaliran!',
    7 => 'Plug-in koji pokusavate da instalirate vec postoji.  Molimo obrisite plugin pre nego ga re-instalirate',
    8 => 'Test Kompatibilnosti Plugina Nije Prosao',
    9 => 'Ovaj plugin zahteva noviju verziju Geeklog-a. Ili azurirajte vasu kopiju <a href="http://www.geeklog.net">Geeklog-a</a> ili nabavite odgovarajucu verziju plugina.',
    10 => '<br' . XHTML . '><b>Trenutno nema instaliranih plugina.</b><br' . XHTML . '><br' . XHTML . '>',
    11 => 'Da izmenite ili obrisete plugin, kliknite na pluginovu ikonicu izmeni prikazanu ispod. Za detaljne informacije o pluginu, kliknite na ime plugina i bicete preusmereni na njegovu web prezentaciju. Da instalirate ili azurirate plugin procitajte njegovu dokumentaciju.',
    12 => 'ime plugina nije poslano za plugineditor()',
    13 => 'Plugin Editor',
    14 => 'Novi plugin',
    15 => 'Administracija',
    16 => 'Plug-in Naziv',
    17 => 'Plug-in Verzija',
    18 => 'Geeklog Verzija',
    19 => 'Omoguci',
    20 => 'Da',
    21 => 'Ne',
    22 => 'Instaliraj',
    23 => 'Sacuvaj',
    24 => 'Otkazi',
    25 => 'Obrisi',
    26 => 'Ime plugina',
    27 => 'Web stranica plugina',
    28 => 'Verzija plugina',
    29 => 'Geeklog Verzija',
    30 => 'Obrisati plugin?',
    31 => 'Da li ste sigurni da zelite da obrisete ovaj plugin?  Ovom operacijom uklonicete sve podatke i strukture podataka koje ovaj plugin koristi.  Ako ste sigurni, kliknite na dugme Obrisi prikazno ispod.',
    32 => '<p><b>Greska AutoLink tag nekorektan format</b></p>',
    33 => 'Verzija Kod-a',
    34 => 'Azuriraj',
    35 => 'Izmeni',
    36 => 'Kod',
    37 => 'Podaci',
    38 => 'Azuriraj!',
    39 => 'Upload a plugin',
    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
    41 => 'Upload',
    42 => 'Click to update',
    99 => 'An unknown error occured',
    100 => 'Ok.',
    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
    103 => 'The uploaded file was only partially uploaded.',
    104 => 'No file was uploaded.',
    105 => '(undefined error)',
    106 => 'Missing a temporary folder.',
    107 => 'Failed to write file to disk.',
    108 => 'File upload stopped by extension.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => 'kreiraj feed',
    2 => 'sacuvaj',
    3 => 'obrisi',
    4 => 'otkazi',
    10 => 'RSS',
    11 => 'Novi Feed',
    12 => 'Administracija',
    13 => 'Da izmenite ili obrisete feed, klikinte na ikonicu izmeni prikaznu ispod. Da kreirate novi feed, kliknite na "Kreiraj Novi" dugme iznad.',
    14 => 'Naslov',
    15 => 'Vrsta',
    16 => 'Ime datoteke',
    17 => 'Format',
    18 => 'Poslednja Obnova',
    19 => 'Omoguci',
    20 => 'Da',
    21 => 'Ne',
    22 => '<i>(nema feedova)</i>',
    23 => 'svi tekstovi',
    24 => 'Feed Editor',
    25 => 'Feed Naslov',
    26 => 'Ogranicenje',
    27 => 'Duzina zapisa',
    28 => '(0 = nema teksta, 1 = kompletan tekst, ostalo = ogranicen broj znakova.)',
    29 => 'Opis',
    30 => 'Poslednja Obnova',
    31 => 'Set Karaktera',
    32 => 'Jezik',
    33 => 'Sadrzaji',
    34 => 'Zapis(a)',
    35 => 'Sat(i)',
    36 => 'Selektuj tip za feed',
    37 => '',
    38 => 'Greska: Nepotpun unos',
    39 => 'Molimo popunite polja Feed Naslov, Opis i Ime Datoteke.',
    40 => 'Molimo unesite broj zapisa ili broj sati.',
    41 => 'Linkovi',
    42 => '',
    43 => 'Sve',
    44 => 'Nista',
    45 => 'Header-link',
    46 => 'Ogranici Rezulate',
    47 => 'Pretraga',
    48 => 'Izmena',
    49 => 'Feed Logo',
    50 => "Relativan u odnosu na url sajta ({$_CONF['site_url']})",
    51 => 'Ime koje ste izabrali je vec u upotrebi od strane drugog feed-a. Molimo izaberite neko drugo.',
    52 => 'Greska: fajl sa ovim imenom vec postoji',
    53 => 'Svi tekstovi sa naslovne strane',
    54 => 'Molimo selektujte tip za feed koji keirate.',
    55 => 'Tekstovi'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "Vasa lozinka je poslata na vasu email adresu. Molimo pratite uputstvo u tekstu poruke i zahvaljujemo Vam sto koristite {$_CONF['site_name']}",
    2 => "Hvala sto ste poslali tekst na {$_CONF['site_name']}. Tekst ce prvo biti procitan od strane admina. Ako tekst bude prihvacen uskoro ce biti javno dostupan na nasim stranicama.",
    3 => '',
    4 => '',
    5 => 'Informacije u vasem profilu su uspesno sacuvane.',
    6 => 'Vase karakteristike su uspesno sacuvane.',
    7 => 'Vase karakteristike za komentare su uspesno sacuvane.',
    8 => 'Uspesno ste odjavljeni.',
    9 => 'Vas tekst je uspesno sacuvan.',
    10 => 'Tekst je uspesno obrisan.',
    11 => 'Vas blok je uspesno sacuvan.',
    12 => 'Blok je uspesno obrisan.',
    13 => 'Vasa kategorija tekstova je uspesno sacuvana.',
    14 => 'Kategorija i svi tekstovi u njoj su uspesno obrisani.',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => 'Korisnik dodat u bazu podataka.',
    22 => 'Korisnik obrisan.',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => 'Poruka je uspesno poslata.',
    28 => 'Plugin je uspesno sacuvan',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => 'Pristup zabranjen',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => 'Sistemska Poruka',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Plugin uspesno instaliran!',
    45 => 'Plugin uspesno ozbrisan.',
    46 => '',
    47 => 'Ove funkcije rade samo pod *nix. Ako koristite *nix kao operativni sistem onda je vas cache uspesno ociscen. Ako koristite Windows, nadjite fajlove po imenu adodb_*.php i uklonite ih manuelno.',
    48 => "Zahvaljujemo Vam sto ste postali clan {$_CONF['site_name']}. Nas tim ce pregledati i oceniti vas zahtev. Ako bude prihvacen vasa lozinka ce Vam biti poslata na email.",
    49 => 'Vasa grupa je uspesno sacuvana.',
    50 => 'Grupa je uspesno obrisana.',
    51 => 'Ovo korisnicko ime je vec u upotrebi. Molimo izaberite drugo.',
    52 => 'Izgleda da email adresa koju ste uneli nije validna.',
    53 => 'Vasa nova lozinka je prihvacena. Molimo koristite vasu novu lozinku da bi se prijavili ispod.',
    54 => 'Vas zahtev za novu lozinku je istekao. Pokusajte ponovo ispod.',
    55 => 'Email Vam je poslat i trebao bi da stigne momentalno. Molimo pratite uputstva u poruci koju ste dobili kako bi postavili novu lozinku za vas korisnicki nalog.',
    56 => 'Ovaj email je vec u upotrebi za drugi nalog.',
    57 => 'Vas nalog je uspesno obrisan.',
    58 => 'Vas feed je uspesno sacuvan.',
    59 => 'Feed je uspesno obrisan.',
    60 => 'Plugin je uspesno azuriran',
    61 => 'Plugin %s: nepoznata placeholder poruka',
    62 => 'Trackback komentar je obrisan.',
    63 => 'Doslo je do greske prilikom brisanja trackback komentara.',
    64 => 'Vas trackback komentar je uspesno poslat.',
    65 => 'Weblog katalog servis uspesno sacuvan.',
    66 => 'Weblog katalog servis je obrisan.',
    67 => 'Nova lozinka se ne podudara sa potvrdnom lozinkom!',
    68 => 'Morate uneti tacnu trenutnu lozinku.',
    69 => 'Vas nalog je blokiran!',
    70 => 'Vas nalog ceka administratorsko odobrenje.',
    71 => 'Vas nalog je sada potvrdjen i ceka administratorsko odobrenje.',
    72 => 'Doslo je do greske prilikom instalacije plugina. Pogledajte error.log za vise detalja.',
    73 => 'Doslo je do greske prilikom deinstalacije plugina. Pogledajte error.log za vise detalja.',
    74 => 'Pingback je uspesno poslat.',
    75 => 'Trackback-ovi moraju biti poslati koriscenjem POST request-a.',
    76 => 'Da li stavrno zelite da obriste ovaj clanak?',
    77 => 'UPOZORENJE:<br' . XHTML . '>Postavili ste UTF-8 kao podrazumevani encoding. Ipak, vas server ne podrzava multibyte encoding. Molimo instalirajte mbstring funkcije za PHP ili izaberite drugi character set/jezik.',
    78 => 'Molimo da proverite da su email adresa i konfirmaciona email adresa identicne.',
    79 => 'Strana koju pokusavate da otvorite se oslanja na funkciju koja vise nije dostupna na ovom sajtu.',
    80 => 'Plugin koji je kreirao ovaj feed je trenutno onemogucen. Niste u mogucnosti da izmenite ovaj feed sve dok ne omogucite koriscenje tog plugina.',
    81 => 'Ocito ste pogresili u unosu vasih korisnickih podataka.  Molimo pokusajte ponovo.',
    82 => 'Premasili ste broj dozvoljenih pokusaja za prijavu.  Molimo pokusajte kasnije.',
    83 => 'Da promenite lozinku, email adresu, ili podatke o tome koliko zelite biti prijavljeni, molimo unesite vasu trenutnu lozinku.',
    84 => 'Da obrisete vas nalog, molimo unesite vasu trenutnu lozinku.',
    85 => 'Doslo je do problema prilikom slanja emaila.',
    86 => 'OpenID server je odbio vas pokusaj prijave.',
    87 => 'OpenID prijavna operacija je prekinuta od strane korisnika.',
    88 => 'OpenID server je vratio gresku.',
    89 => 'Nisam u mogucnosti da pronadjem OpenID server sa datim identity URL-om.',
    90 => 'OpenID identifikacija prekinuta.',
    91 => 'Dostavili ste neispravan identity URL.',
    92 => "Molimo <a href=\"{$_CONF['site_admin_url']}/sectest.php\">proverite sigurnost vaseg sajta</a> pre nego pocnete njegovo koriscenje!",
    93 => 'Backup baze je uspesan!.',
    94 => 'Backup Nije Uspeo: Velicina fajla je manja od 1kb',
    95 => 'Pojavila se Greska.',
    96 => '',
    97 => '',
    98 => 'The plugin was successfully uploaded.',
    99 => 'The plugin already exists.',
    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
    400 => 'Not all required fields have been passed validation',
    401 => 'Please enter Fullname'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => 'Pristup',
    'ownerroot' => 'Vlasnik/Root',
    'group' => 'Grupa',
    'readonly' => 'Samo Citanje',
    'accessrights' => 'Prava Pristupa',
    'owner' => 'Vlasnik',
    'grantgrouplabel' => 'Omoguci Grupi Pravo Na Izmene',
    'permmsg' => 'NAPOMENA: clanovi su svi ulogovani clanovi na sajtu a anonimus je bilo koji korisnik koji gleda sajt a nije prijavljen.',
    'securitygroups' => 'Sigurnosne grupe',
    'editrootmsg' => "Iako ste Vi Administrator, nemozete izmeniti root korisnika ukoliko sami niste root korisnik. Mozete menjati sve druge korisnike osim root korisnika. Molimo zapamtite da se svi pokusaji za nedozvoljenu izmenu root korisnika beleze.  Molimo vratite se nazad na <a href=\"{$_CONF['site_admin_url']}/user.php\">stranu za administriranje korisnika</a>.",
    'securitygroupsmsg' => 'Selektuj checkboxove za grupe kojima zelis da ovaj korisnik pripada.',
    'groupeditor' => 'Editor Grupa',
    'description' => 'Opis',
    'name' => 'Ime',
    'rights' => 'Prava',
    'missingfields' => 'Polja koja nedostaju',
    'missingfieldsmsg' => 'Morate uneti ime i opis grupe',
    'groupmanager' => 'Menadzer Korisnickih Grupa',
    'newgroupmsg' => 'Da izmenite ili obrisete grupu, kliknite na ikonicu u "Izmeni" polju. Da kreirate novu grupu kliknite na "Kreiraj Novi" iznad. Molimo zapamtite da glavne/core grupe nije moguce obrisati jer sistem koristi iste.',
    'groupname' => 'Ime grupe',
    'coregroup' => 'Sistemska grupa',
    'yes' => 'Da',
    'no' => 'Ne',
    'corerightsdescr' => "Ova grupa je core {$_CONF['site_name']} Grupa.  Zato prava za ovu grupu nije moguce menjati.  Ispod je lista Samo Citanje za sva prava kojima ova grupa ima pristup.",
    'groupmsg' => 'Sigurnosne Grupe na ovom sajtu su hijerarhijski organizovane.  Dodavanjem ove grupe u bilo koju od grupa ispod omogucicete joj identicna prava koja imaju ove grupe.  U koliko je to moguce preporucuje se da se koriste bas ove grupe kako bi se novoj grupi dala prava.  Ako Vam je neophodno da ova grupa ima specificna prava, onda mozete slektovati ista za razlicite opcije sajta u sekciji "Prava" koja je prikazana ispod.  Da dodate grupu u bilo koju od ovih prikazanih ispod, jednostavno cekirajte box od same grupe koju zelite.',
    'coregroupmsg' => "Ova grupa je core {$_CONF['site_name']} Grupa.  Zato prava za ovu grupu nije moguce menjati.  Ispod je lista Samo Citanje za sva prava kojima ova grupa ima pristup.",
    'rightsdescr' => 'Samoj grupi je moguce dodeliti direktna odredjena prava prikazana ispod ILI drugoj grupi ako je ova grupa njen clan.  Stavke koje vidite ispod bez checkboxa su prava koja su grupi dodeljena zato sto ona pripada drugoj grupi koja ima ta prava.  Prava koja imaju checkboxove pored sebe su prava koja mozete omoguciti za grupu koju kreirate.',
    'lock' => 'Zakljucaj',
    'members' => 'Clanovi',
    'anonymous' => 'Anonimus',
    'permissions' => 'Prava',
    'permissionskey' => 'R = cita, E = Menja, pravo menjanja ukljucuje i pravo citanja',
    'edit' => 'Izmeni',
    'none' => 'Nista',
    'accessdenied' => 'Pristup Zabranjen',
    'storydenialmsg' => "Nemate prava za pregled ovog teksta.  Moguce je da niste clan {$_CONF['site_name']}.  Molimo <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">postanite clan</a> of {$_CONF['site_name']} kako bi imali sve clanske privilegije!",
    'nogroupsforcoregroup' => 'Ova grupa ne pridapda nijednoj od ostalih grupa',
    'grouphasnorights' => 'Ova grupa nema pristup nijednoj od administratorskih mogucnosti na ovom sajtu',
    'newgroup' => 'Nova Grupa',
    'adminhome' => 'Admin Home',
    'save' => 'sacuvaj',
    'cancel' => 'otkazi',
    'delete' => 'obrisi',
    'canteditroot' => 'Pokusali ste da izmenite Root grupu ali sami ne pripdate Root grupi, zato Vam je zapranjen pristup.  Molimo kontaktirajte administratora ako ovo smatrate greskom!',
    'listusers' => 'Lista Korisnika',
    'listthem' => 'lista',
    'usersingroup' => 'Korisnici u grupi "%s"',
    'usergroupadmin' => 'Administrator Korisnicke Grupe',
    'add' => 'Dodaj',
    'remove' => 'Ukloni',
    'availmembers' => 'Dostupni clanovi',
    'groupmembers' => 'Clanovi grupe',
    'canteditgroup' => 'Da izmenite ovu grupu, morate biti njen clan. Molimo kontaktirajte administratora ako ovo smatrate greskom!',
    'cantlistgroup' => 'Da vidite clanove ove grupe, sami morate biti clan iste. Molimo kontaktirajte administratora ako ovo smatrate greskom!',
    'editgroupmsg' => 'Da izmenite pripadnost grupi, kliknite na ime clana(ova) i koristite dodaj ili ukloni dugmad. Ako je korisnik clan grupe, njegovo ime ce se prikazati samo sa desne strane. Kada zavrsite pritisnite <b>Sacuvaj</b> da azurirate grupu i vratite se na glavnu admin stranu za grupe.',
    'listgroupmsg' => 'Prikaz svih clanova u grupi: <b>%s</b>',
    'search' => 'Pretraga',
    'submit' => 'Posalji',
    'limitresults' => 'Ogranici Rezultate',
    'group_id' => 'Grupa ID',
    'plugin_access_denied_msg' => 'Pokusavate nedozvoljeno da pristupite plugin administratorskoj strani.  Molimo zapamtite da se svi pokusaji nelegalnih pristupa ovoj strani beleze.',
    'groupexists' => 'Grupa sa ovim imenom vec postoji',
    'groupexistsmsg' => 'Grupa sa ovim imenom je vec definisana. Imena grupa moraju biti jedinstvena.'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => 'Sigurnosne kopije baze podataka.',
    'do_backup' => 'Napravi sigurnosnu kopiju',
    'backup_successful' => 'Sigurnosna kopija baze podataka je uspesno napravljena.',
    'db_explanation' => 'Da bi napravili sigurnosu kopiju vase baze (BACKUP) kliknite na duge "Kreiraj Novi" iznad. Kliknite na ime fajla kako bi ga preuzeli',
    'not_found' => "Putanja nije korektna ili nije moguce pokrenuti mysqldump alatku.<br" . XHTML . ">Proverite <strong>\$_DB_mysqldump_path</strong> varijablu u vasem config.php.<br" . XHTML . ">Varijabla je trenutno definisana kao: <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => 'Kreiranje sigurnosne kopije nije uspelo: Velicina fajla je 0 bytes',
    'path_not_found' => "{$_CONF['backup_path']} nepostoji ili nije direktorijum",
    'no_access' => "GRESKA: Direktorijum {$_CONF['backup_path']} nije dostupan.",
    'backup_file' => 'Fajl sigurnosne kopije',
    'size' => 'Velicina',
    'bytes' => 'Bytes',
    'total_number' => 'Ukupan broj sigurnosnih kopija: %d',
    'download' => 'Klikni da preuzmes fajl',
    'new_backup' => 'New Backup',
    'delete_failure' => 'One or more backup files could not be deleted.',
    'delete_success' => 'Backup file(s) successfully deleted.',
    'convert_menu' => 'Convert to InnoDB',
    'convert_title' => 'Convert to InnoDB tables',
    'convert_button' => 'Convert',
    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
    'innodb_success' => 'Successfully converted tables to InnoDB.',
    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
    'optimize_menu' => 'Optimize Tables',
    'optimize_title' => 'Optimize Tables',
    'optimize_button' => 'Optimize',
    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
    'last_optimization' => 'Last optimization',
    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
    'optimize_success' => 'Successfully optimized database tables.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => 'Pocetna Strana',
    2 => 'Kontakt',
    3 => 'Posaljite Tekst',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Statistike Sajta',
    8 => 'Personalizacija',
    9 => 'Pretraga',
    10 => 'napredna pretraga',
    11 => 'Katalog'
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => '404 Error',
    2 => 'Trazio sam svuda ali nisam uspeo da pronadjem <b>%s</b>.',
    3 => "<p>Zao nam je, ali fajl koji ste trazili ne postoji. Mozda da odete na <a href=\"{$_CONF['site_url']}\">naslovnu stranu</a> ili da probate <a href=\"{$_CONF['site_url']}/search.php\">da pronadjete</a> to sto ste trazili."
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => 'Potrebna prijava',
    2 => 'Zao nam je, Da bi pristupili ovom delu morate biti prijavljeni...',
    3 => 'Prijava',
    4 => 'Novi korisnik'
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => 'Trackback',
    'from' => 'od',
    'tracked_on' => 'Track ukljucen',
    'read_more' => '[detaljnije]',
    'intro_text' => 'Evo sta drugi imaju da kazu o \'%s\':',
    'no_comments' => 'Nema trackback komentara za ovaj zapis.',
    'this_trackback_url' => 'Trackback URL za ovaj zapis:',
    'num_comments' => '%d trackback komentari',
    'send_trackback' => 'Posalji Pingove',
    'preview' => 'Pregled',
    'editor_title' => 'Posalji trackback komentar',
    'trackback_url' => 'Trackback URL',
    'entry_url' => 'URL Zapisa',
    'entry_title' => 'Naslov Zapisa',
    'blog_name' => 'Ime Sajta',
    'excerpt' => 'Odlomak',
    'truncate_warning' => 'Napomena: Sajt primalac moze odbaciti vas odlomak',
    'button_send' => 'Posalji',
    'button_preview' => 'Pregled',
    'send_error' => 'Greska',
    'send_error_details' => 'Greska pri slanju trackback komentara:',
    'url_missing' => 'URL Zapisa Nije Nadjen',
    'url_required' => 'Molimo unesite najmanje 1 URL za zapis.',
    'target_missing' => 'Nema Trackback URL-a',
    'target_required' => 'Molimo unesite trackback URL',
    'error_socket' => 'Ne mogu da otvorim socket.',
    'error_response' => 'Odgovor nije razumljiv.',
    'error_unspecified' => 'Nepoznata greska.',
    'select_url' => 'Izaberi Trackback URL',
    'not_found' => 'Trackback URL nije pronadjen',
    'autodetect_failed' => 'Geeklog nije u stanju da detektuje Trackback URL za tekst koji zelite da komentarisete. Molimo unesite ga manuelno ispod.',
    'trackback_explain' => 'Od linkova ispod, molimo izaberite URL na koji zelite da posaljete vas Trackback komentar. Geeklog ce onda pokusati da pronadje tacan Trackback URL za taj tekst. Ili ga mozete zadati <a href="%s">manuelno</a> ako ga vec znate.',
    'no_links_trackback' => 'Linkovi nisu pronadjeni. Nemozete poslati Trackback komentar za ovaj zapis.',
    'pingback' => 'Pingback',
    'pingback_results' => 'Pingback rezulati',
    'send_pings' => 'Posalji Pingove',
    'send_pings_for' => 'Posalji Pingove za "%s"',
    'no_links_pingback' => 'Linkovi nisu pronadjeni. Pingbackovi nisu poslati za ovaj zapis.',
    'pingback_success' => 'Pingback poslat.',
    'no_pingback_url' => 'Pingback URL nije pronadjen.',
    'resend' => 'Ponovo Posalji',
    'ping_all_explain' => 'Mozete obavestiti sajtove koje linkujete sa (<a href="http://en.wikipedia.org/wiki/Pingback">Pingback</a>), oglasite da je vas sajt azuriran pingovanjem weblog katalog servisa, ili posaljite <a href="http://en.wikipedia.org/wiki/Trackback">Trackback</a> komentar u slucaju da ste pisali o tekstu sa nekog drugog sajta.',
    'pingback_button' => 'Posalji Pingback',
    'pingback_short' => 'Posalji Pingbackove svim sajtovima koji su linkovani u ovom zapisu.',
    'pingback_disabled' => '(Pingback onemogucen)',
    'ping_button' => 'Posalji Ping',
    'ping_short' => 'Ping weblog katalog servisa.',
    'ping_disabled' => '(Ping onemogucen)',
    'trackback_button' => 'Posalji Trackback',
    'trackback_short' => 'Posalji Trackback komentar.',
    'trackback_disabled' => '(Trackback onemogucen)',
    'may_take_a_while' => 'Molimo zapamtite da  slanje Pingback-ova i Ping-ova moze potrajati.',
    'ping_results' => 'Ping rezulati',
    'unknown_method' => 'Nepoznat ping method',
    'ping_success' => 'Ping poslat.',
    'error_site_name' => 'Molimo unesite ime sajta.',
    'error_site_url' => 'Molimo unesite URL sajta.',
    'error_ping_url' => 'Molimo unesite validan Ping URL.',
    'no_services' => 'Weblog katalog servisi nisu konfigurisani.',
    'services_headline' => 'Weblog Katalog servisi',
    'service_explain' => 'Da izmenite ili obrisete weblog katalog servis, kliknite na ikonicu u "Izmeni" polju ispod. Da dodate novi weblog katalog servis kliknite na "Kreiraj Novi" iznad.',
    'service' => 'Servis',
    'ping_method' => 'Ping Metod',
    'service_website' => 'Web Sajt',
    'service_ping_url' => 'Url Za Ping',
    'ping_standard' => 'Standard Ping',
    'ping_extended' => 'Extended Ping',
    'ping_unknown' => '(nepoznat metod)',
    'edit_service' => 'Izmeni Weblog Katalog Servis',
    'trackbacks' => 'Trackbacks',
    'editor_intro' => 'Pripremite vas trackback komentar za <a href="%s">%s</a>.',
    'editor_intro_none' => 'Pripremite vas trackback komentar.',
    'trackback_note' => 'Da posaljete trackback komentar za tekst, idite na listu tekstova i kliknite na "Posalji Ping" za tekst. Da posaljte trackback koji nije povezan sa tekstom, <a href="%s">kliknite ovde</a>.',
    'pingback_explain' => 'Unesite URL kojem saljete Pingback. Pingback ce "udarati" na vasu naslovnu stranu.',
    'pingback_url' => 'Pingback URL',
    'site_url' => 'URL Ovoga Sajta',
    'pingback_note' => 'Da posaljete pingback komentar za tekst, idite na listu tekstova i kliknite na "Posalji Ping" za tekst. Da posaljte pingback koji nije povezan sa tekstom, <a href="%s">kliknite ovde</a>.',
    'pbtarget_missing' => 'Nema Pingback URL-a',
    'pbtarget_required' => 'Molimo unesite pingback URL',
    'pb_error_details' => 'Greska prilikom slanja pingback-a:',
    'delete_trackback' => 'Da obrisete ovaj Trackback kliknite: '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => 'Katalog Tekstova',
    'title_year' => 'Katalog Tekstova %d',
    'title_month_year' => 'Katalog Tekstova za %s %d',
    'nav_top' => 'Nazad na Katalog Tekstova',
    'no_articles' => 'Nema tekstova.'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Geeklog Security Check',
    'results' => 'Results of the Security Check',
    'okay' => 'Everything seems to be in order.',
    'please_fix' => 'Please fix the above issues before using your site!',
    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
    'installation' => 'installation instructions',
    'directory' => 'directory',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'This is a security risk and should be fixed!',
    'reachable' => 'Your %s is reachable from the web.',
    'not_reachable' => 'Good! Your %s is not reachable from the web.',
    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
    'inst_removed' => 'Good! You seem to have removed the install directory already.',
    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
    'password_okay' => 'Good! You seem to have changed the default account password already.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n novi(a) %i u poslednjih %t %s',
    'new_last' => 'u poslednjih %t %s',
    'minutes' => 'minuta',
    'hours' => 'sata',
    'days' => 'dana',
    'weeks' => 'nedelje(a)',
    'months' => 'meseci',
    'minute' => 'minuta',
    'hour' => 'sat',
    'day' => 'dan',
    'week' => 'nedelja',
    'month' => 'mesec'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => 'Januar',
    2 => 'Februar',
    3 => 'Mart',
    4 => 'April',
    5 => 'Maj',
    6 => 'Jun',
    7 => 'Jul',
    8 => 'Avgust',
    9 => 'Septembar',
    10 => 'Oktobar',
    11 => 'Novembar',
    12 => 'Decembar'
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => 'Nedelja',
    2 => 'Ponedeljak',
    3 => 'Utorak',
    4 => 'Sreda',
    5 => 'Cetvrtak',
    6 => 'Petak',
    7 => 'Subota'
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => 'Pretraga',
    'limit_results' => 'Ogranici Rezultate',
    'submit' => 'Posalji',
    'edit' => 'Izmeni',
    'edit_adv' => 'Izmeni (Nap.)',
    'admin_home' => 'Admin Home',
    'create_new' => 'Kreiraj Novi',
    'create_new_adv' => 'Kreiraj Novi (Nap.)',
    'enabled' => 'Omoguci',
    'title' => 'Naslov',
    'type' => 'Tip',
    'topic' => 'Kategorija',
    'help_url' => 'URL Do Help Fajla',
    'save' => 'Sacuvaj',
    'cancel' => 'Otkazi',
    'delete' => 'Obrisi',
    'delete_sel' => 'Obrisi selektovano',
    'copy' => 'Kopiraj',
    'no_results' => '- Zapisi nisu pronadjeni -',
    'data_error' => 'Doslo je do greske prilikom procesriranja subscription podataka. Molimo proverite izvor podataka.',
    'preview' => 'Pregled',
    'records_found' => 'Pranadjenih rezultata',
    'addchild' => 'Dodaj dete',
    'list' => 'prikazi',
    'list_all' => 'Prikazi sve',
    'meta_description' => 'Meta Description',
    'meta_keywords' => 'Meta Keywords',
    'na' => 'N/A',
    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => 'Komentari Omoguceni',
    -1 => 'Komentari Blokirani',
    1 => 'Komentari Zatvoreni'
);

$LANG_commentmodes = array(
    'flat' => 'Pausalan',
    'nested' => 'Uklopljen',
    'threaded' => 'Sa navojem',
    'nocomment' => 'Nema Komentara'
);

$LANG_cookiecodes = array(
    0 => '(nemoj)',
    3600 => '1 Sat',
    7200 => '2 Sata',
    10800 => '3 Sata',
    28800 => '8 Sati',
    86400 => '1 Dan',
    604800 => '1 Nedelja',
    2678400 => '1 Mesec'
);

$LANG_dateformats = array(
    0 => 'System Default'
);

$LANG_featurecodes = array(
    0 => 'Nije Uoblicen',
    1 => 'Uoblicen'
);

$LANG_frontpagecodes = array(
    0 => 'Prikazi samo u Kategoriji',
    1 => 'Prikazi na Naslovnoj Strani'
);

$LANG_postmodes = array(
    'plaintext' => 'Obican tekst',
    'html' => 'HTML Format'
);

$LANG_sortcodes = array(
    'ASC' => 'Prvo Najstarije',
    'DESC' => 'Prvo Najnovije'
);

$LANG_trackbackcodes = array(
    0 => 'Trackback Omogucen',
    -1 => 'Trackback Onemogucen'
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Home',
    'admin_home' => 'Administracija Sajta',
    'sections' => 'Konfiguracijske Sekcije',
    'restore' => 'Restore',
    'add_element' => 'Dodaj Element',
    'save_changes' => 'Sacuvaj Promene',
    'reset_form' => 'Resetuj Formu',
    'changes_made' => 'Promene su uspesne za',
    'title' => 'Konfiguracioni Menadzer',
    'disable' => 'Klikni da onemogucis ovu opciju',
    'enable' => 'Enable'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Geeklog Konfiguracija'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'HTML Putanja',
    'site_url' => 'URL Sajta',
    'site_admin_url' => 'Administratorski URL',
    'site_mail' => 'E-Mail Sajta',
    'noreply_mail' => 'No-Reply E-Mail',
    'site_name' => 'Ime Sajta',
    'site_slogan' => 'Slogan',
    'microsummary_short' => 'Microsummary',
    'path_log' => 'Logovi',
    'path_language' => 'Jezici',
    'backup_path' => 'Backup',
    'path_data' => 'Podaci',
    'path_images' => 'Slike',
    'path_pear' => 'Pear Biblioteka',
    'have_pear' => 'Imate Pear Biblioteku?',
    'mail_settings' => 'Mail Podesavanja',
    'allow_mysqldump' => 'Dozvoli MySQL Dump',
    'mysqldump_path' => 'Putanja Do Izvrsnog Fajla',
    'mysqldump_options' => 'MySQL Dump Opcije',
    'mysqldump_filename_mask' => 'Backup File Name Mask',
    'theme' => 'Tema',
    'doctype' => 'DOCTYPE Declaration',
    'menu_elements' => 'Elementi Menija',
    'path_themes' => 'Putanja Za Teme',
    'disable_new_user_registration' => 'Onemoguci Nove Registracije',
    'allow_user_themes' => 'Dozvoli Korisnicke Teme',
    'allow_user_language' => 'Dozvoli Korisnicke Jezike',
    'allow_user_photo' => 'Dozvoli Korisnicke Fotografije',
    'allow_username_change' => 'Dozvoli Promenu Korisnickog Imena',
    'allow_account_delete' => 'Dozvoli Brisanje Naloga',
    'hide_author_exclusion' => 'Dozvoli Sakrivanje Autora',
    'show_fullname' => 'Prikazi Puno Ime',
    'show_servicename' => 'Prikazi Ime Servisa',
    'custom_registration' => 'Omoguci Prilagodjenu/Custom Registraciju',
    'user_login_method' => 'Metod Korisnicke Prijave',
    'spamx' => 'Spam-X Akcije',
    'sort_admin' => 'Sortiraj Linkove',
    'language' => 'Jezik',
    'locale' => 'Lokalizacija',
    'date' => 'Format Datuma',
    'daytime' => 'Format Vremena',
    'shortdate' => 'Kratki Datum Format',
    'dateonly' => 'Samo Datum Format',
    'timeonly' => 'Samo Vremenski Format',
    'week_start' => 'Nedelja Pocinje Od',
    'hour_mode' => 'Satni Rezim',
    'thousand_separator' => 'Hiljaditi Separator',
    'decimal_separator' => 'Decimalni Separator',
    'decimal_count' => 'Decimalni Brojac',
    'language_files' => 'Jezicki Fajlovi',
    'languages' => 'Jezici',
    'timezone' => 'Vremenska Zona',
    'site_disabled_msg' => 'Poruka ili URL kada Sajt nije Dostupan',
    'rootdebug' => 'Root Debugging',
    'cookie_session' => 'Session Cookie Naziv',
    'cookie_name' => 'Naziv Permanentnog Kolacica',
    'cookie_password' => 'Naziv Kolacica Lozinke',
    'cookie_theme' => 'Naziv Kolacica teme',
    'cookie_language' => 'Naziv Jecickog Kolacica',
    'cookie_tzid' => 'Naiv Kolacica Vremenske Zone',
    'cookie_anon_name' => 'Anon. Username Cookie Name',
    'cookie_ip' => 'Kolacici Sadrze IP?',
    'default_perm_cookie_timeout' => 'Permanent Timeout',
    'session_cookie_timeout' => 'Timeout Sesije',
    'cookie_path' => 'Putanja Kolacica',
    'cookiedomain' => 'Domen Kolacica',
    'cookiesecure' => 'Bezbednost Kolacica',
    'lastlogin' => 'Pamti Poslednju Prijavu?',
    'num_search_results' => 'Broj Rezultata U Pretrazi',
    'loginrequired' => 'Prijava Obavezna?',
    'submitloginrequired' => 'Doprinosi - Prijava Obavezna?',
    'commentsloginrequired' => 'Komentari - Prjava Obavezna?',
    'statsloginrequired' => 'Statistika - Prijava Obavezna?',
    'searchloginrequired' => 'Pretraga - Prijava Obavezna?',
    'profileloginrequired' => 'Profil - Prijava Obavezna?',
    'emailuserloginrequired' => 'E-Mail Ka Korisniku - Prijava Obavezna?',
    'emailstoryloginrequired' => 'E-Mail Teksta - Prijava Obavezna?',
    'directoryloginrequired' => 'Katalog - Prijava Obavezna?',
    'storysubmission' => 'Red Tekstovnih Doprinosa?',
    'usersubmission' => 'Red Korisnickih Doprinosa?',
    'listdraftstories' => 'Prikazi Draft-ovane Tekstove?',
    'notification' => 'Obavestenja',
    'postmode' => 'Podrazumevani Tekst Rezim',
    'speedlimit' => 'Ogranicenje Brzine Tekstova',
    'skip_preview' => 'Preskoci Pregled u Tekstovima',
    'advanced_editor' => 'Napredni Editor?',
    'wikitext_editor' => 'Wikitext Editor?',
    'cron_schedule_interval' => 'Cron Dispecer Interval',
    'sortmethod' => 'Sortiraj Kategorije',
    'showstorycount' => 'Prikazi Brojac Tekstova?',
    'showsubmissioncount' => 'Prikazi Brojac Doprinosa?',
    'hide_home_link' => 'Sakrij Home Link?',
    'whosonline_threshold' => 'Threshold Sesija',
    'whosonline_anonymous' => 'Sakrij Imena Od Gostiju?',
    'emailstories' => 'Dnevni Digest Omogucen?',
    'emailstorieslength' => 'Duzina Tekstova',
    'emailstoriesperdefault' => 'Omoguci za Nove Korisnike?',
    'allow_domains' => 'Dozvoli Domain Automatizaciju',
    'disallow_domains' => 'Automatski Zabrani Domene',
    'newstoriesinterval' => 'Interval Novih Tekstova',
    'newcommentsinterval' => 'Interval Novih Komentara',
    'newtrackbackinterval' => 'Interval Novih Trackbacks',
    'hidenewstories' => 'Sakrij Nove Tekstove',
    'hidenewcomments' => 'Sakrij Nove Komentare',
    'hidenewtrackbacks' => 'Sakrij Nove Trackbacks',
    'hidenewplugins' => 'Sakrij Nove Plugin Zapise',
    'title_trim_length' => 'Duzina Isecka Naslova',
    'trackback_enabled' => 'Trackback Omogucen?',
    'pingback_enabled' => 'Pingback Omogucen?',
    'ping_enabled' => 'Ping Omogucen?',
    'trackback_code' => 'Trackback Podrazumevan',
    'multiple_trackbacks' => 'Visestruki Trackbacks',
    'trackbackspeedlimit' => 'Trackback Ogranicenje Brzine',
    'check_trackback_link' => 'Proveri Trackbacks',
    'pingback_self' => 'Pingback Ka Sebi?',
    'pingback_excerpt' => 'Kreiraj Pingback Izvod?',
    'link_documentation' => 'Link ka Dokumentaciji?',
    'link_versionchecker' => 'Link ka Version Checker-u?',
    'maximagesperarticle' => 'Max Slika po Tekstu',
    'limitnews' => 'Tekstova Po Strani',
    'minnews' => 'Min. Tekstova Po Strani',
    'contributedbyline' => 'Prikazi Autora?',
    'hideviewscount' => 'Sakrij Brojac Pregleda?',
    'hideemailicon' => 'Sakrij E-Mail Ikonu?',
    'hideprintericon' => 'Sakrij Print Ikonu?',
    'allow_page_breaks' => 'Omoguci Prelamanje Strane?',
    'page_break_comments' => 'Komentari Na Visestranim Tekstovima',
    'article_image_align' => 'Poravnanje Ikone Kategorije',
    'show_topic_icon' => 'Prikazi Ikonu Kategorije?',
    'draft_flag' => 'Draft Zastava Podrazumevana',
    'frontpage' => 'Naslovna Podrazumevana',
    'hide_no_news_msg' => 'Sakrij "Nema Tx" Poruka?',
    'hide_main_page_navigation' => 'Sakrij Navigaciju Glavne Strane?',
    'onlyrootfeatures' => 'Samo za Root-a',
    'aftersave_story' => 'Nakon Dodavanja Teksta',
    'aftersave_user' => 'Nakon Dodavanja Korisnika',
    'show_right_blocks' => 'Uvek Prikazi Desne Blokove?',
    'showfirstasfeatured' => 'Uoblici Prvu Pricu?',
    'backend' => 'Omoguci Feedove?',
    'rdf_file' => 'Izlazni RSS Folder',
    'rdf_limit' => 'Feed Limit',
    'rdf_storytext' => 'Duzina Tekstova U Feed-u',
    'rdf_language' => 'Feed Jezik',
    'syndication_max_headlines' => 'Max. Broj Naslova (portal blokova)',
    'copyrightyear' => 'Copyright Godina',
    'image_lib' => 'Image Library',
    'path_to_mogrify' => 'Putanja za Mogrify',
    'path_to_netpbm' => 'Putanja za Netpbm',
    'debug_image_upload' => 'Debug Image Uploading?',
    'keep_unscaled_image' => 'Zadrzi Orginalnu Sliku?',
    'allow_user_scaling' => 'Omoguci Korisnicko Skaliranje?',
    'jpeg_quality' => 'JPEG Quality?',
    'max_image_width' => 'Max Sirina Slike?',
    'max_image_height' => 'Max Visina Slike?',
    'max_image_size' => 'Max Velicina Slike?',
    'max_topicicon_width' => 'Max Sirina Ikone Za Kategoriju?',
    'max_topicicon_height' => 'Max Visina Ikone Za Kategoriju?',
    'max_topicicon_size' => 'Max Velicina Ikone Za Kategoriju?',
    'max_photo_width' => 'Max Sirina Fotografije?',
    'max_photo_height' => 'Max Visina Fotografije?',
    'max_photo_size' => 'Max Velicina Fotografije?',
    'use_gravatar' => 'Koristi Gravatar?',
    'gravatar_rating' => 'Rejting Gravatar-a Dozvoljen',
    'force_photo_width' => 'Prisili Sirinu Slike',
    'default_photo' => 'Podrazumevana Fotografija',
    'commentspeedlimit' => 'Ogranicenje Brzine Komentara',
    'comment_limit' => 'Ogranicenje Komentara',
    'comment_mode' => 'Rezim Komentara',
    'comment_code' => 'Komentari Podrazumevano',
    'comment_edit' => 'Allow Comment Edit?',
    'comment_edittime' => 'Comment Edit Time (seconds)',
    'commentsubmission' => 'Queue Comment Submissions',
    'passwordspeedlimit' => 'Ogranicenje Brzine Lozinke',
    'login_attempts' => 'Max. Broj Pokusaja Prijave',
    'login_speedlimit' => 'Ogranicenje Brzine Prijave',
    'user_html' => 'Korisnicki HTML',
    'admin_html' => 'Admin HTML',
    'advanced_html' => 'Additional HTML for Adv. Editor',
    'skip_html_filter_for_root' => 'Izostavi HTML Filter za Root-a?',
    'allowed_protocols' => 'Dozvoljeni Protokoli',
    'disable_autolinks' => 'Onemoguci Autolikove?',
    'clickable_links' => 'Make URLs clickable?',
    'compressed_output' => 'Send compressed output?',
    'frame_options' => 'Protection against "clickjacking"',
    'censormode' => 'Rezim Cenzure?',
    'censorreplace' => 'Cenzurisana Zamena Teksta',
    'censorlist' => 'Cenzurisana Lista',
    'ip_lookup' => 'IP Lookup',
    'url_rewrite' => 'Omoguci URL Rewrite',
    'meta_tags' => 'Meta Tags',
    'meta_description' => 'Default Meta Description',
    'meta_keywords' => 'Default Meta Keywords',
    'default_permissions_block' => 'Blok Podrazumevane Dozvole',
    'default_permissions_story' => 'Tekst Podrazumevane Dozvole',
    'default_permissions_topic' => 'Kategorija Podrazumevane Dozvole',
    'atom_max_stories' => 'Max. Tekstova u Webservis Feed-u',
    'disable_webservices' => 'Onemoguci Webservise?',
    'restrict_webservices' => 'Zabrani Webservise?',
    'article_comment_close_enabled' => 'Automatically close comments (default)',
    'article_comment_close_days' => 'Days to close comments (default)',
    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
    'allow_reply_notifications' => 'Allow comment reply notifications?',
    'search_style' => 'Results List Style',
    'search_limits' => 'Page Limits',
    'search_show_num' => 'Show Result Number?',
    'search_show_type' => 'Show Result Type?',
    'search_show_sort' => 'Allow User to Sort Results?',
    'search_show_limit' => 'Show Page Limits?',
    'search_separator' => 'Group Separator',
    'search_def_keytype' => 'Default Search Method'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Sajt',
    'sg_stories' => 'Tekstovi i Trackback',
    'sg_theme' => 'Teme',
    'sg_blocks' => 'Blokovi',
    'sg_users' => 'Korisnici i Doprinosi',
    'sg_images' => 'Slike',
    'sg_locale' => 'Jezici i Lokalizacija',
    'sg_misc' => 'Razno'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Sajt',
    'fs_paths' => 'Putanje',
    'fs_theme' => 'Teme',
    'fs_mail' => 'Mail',
    'fs_pear' => 'Pear Biblioteka',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Korisnici',
    'fs_misc' => 'Razno',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Admin Blok',
    'fs_locale' => 'Lokalizacija',
    'fs_language' => 'Jezik',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Kolacici',
    'fs_login' => 'Podesavanje Prijava',
    'fs_search' => 'Pretraga',
    'fs_user_submission' => 'Korisnicki Doprinosi',
    'fs_submission' => 'Podesavnja Doprisnosa (Submissions)',
    'fs_topics_block' => 'Blok Kategorija',
    'fs_whosonline_block' => 'Ko Je Online Blok',
    'fs_daily_digest' => 'Daily Digest',
    'fs_whatsnew_block' => 'Sta Je Novo Blok?',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Tekst',
    'fs_theme_advanced' => 'Napredna Podesavaja',
    'fs_syndication' => 'RSS',
    'fs_imagelib' => 'Image Library',
    'fs_upload' => 'Upload',
    'fs_articleimg' => 'Slike u Tekstovima',
    'fs_topicicon' => 'Ikone Kategorija',
    'fs_userphoto' => 'Fotografija',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Komentari',
    'fs_htmlfilter' => 'HTML Filtriranje',
    'fs_censoring' => 'Cenzurisanje',
    'fs_iplookup' => 'IP Lookup',
    'fs_perm_story' => 'Tekst Podrazumevane Dozvole',
    'fs_perm_topic' => 'Kategorija Podrazumevane Dozvole',
    'fs_perm_block' => 'Blok Podrazumevane Dozvole',
    'fs_webservices' => 'Web Servisi'
);

$LANG_configselects['Core'] = array(
    0 => array('DA' => 1, 'NE' => 0),
    1 => array('DA' => true, 'NE' => false),
    2 => array('Odbaci' => 0, 'Zadrzi Samo Poslednje' => 1, 'Dozvoli Visestruke Tekstove' => 2),
    3 => array('Trackback Omogucen' => 0, 'Trackback Onemogucen' => -1),
    4 => array('Ne Proveravaj Nista' => 0, 'Proveri suprotni Sajt URL' => 1, 'Proveri kompletan URL' => 2, 'Proveri suprotni i kompletan URL' => 3, 'Porveri IP suprotnog Sajta' => 4, 'Proveri IP i Sajt URL' => 5, 'Proveri IP kompletan URL' => 6, 'Proveri IP, Kompletan URL, I Sajt URL' => 7),
    5 => array('Obican tekst' => 'plaintext', 'HTML Format' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Last Page' => 'poslednja', 'First Page' => 'prva', 'Every Page' => 'sve'),
    8 => array('Desno' => 'right', 'Levo' => 'left'),
    9 => array('Prebaci na stranicu' => 'item', 'Prikazi Listu' => 'list', 'Prikazi Naslovnu' => 'home', 'Prikazi Administraciju' => 'admin'),
    10 => array('Nijedna' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('Pausalan' => 'flat', 'Uklopljen' => 'nested', 'Sa navojem' => 'threaded', 'Nema Komentara' => 'nocomment'),
    12 => array('Nema pristup' => 0, 'Samo Citanje' => 2, 'Citanje-Pisanje' => 3),
    13 => array('Preskoci' => 0, 'Omoguci, sa ogranicenjem brzine' => 1, 'Omoguci, bez ogranicenja brzine' => 2),
    14 => array('Nedelje' => 'Sun', 'Ponedeljka' => 'Mon'),
    15 => array('Po Rednom Broju' => 'sortnum', 'Leksikografski' => 'alpha'),
    16 => array('Prijava Nije Obavezna' => 0, 'Samo Napredna Pretraga' => 1, 'Jednostavna + Napredna Pretraga' => 2),
    17 => array('Komentari Omoguceni' => 0, 'Komentari Onemoguceni' => -1),
    18 => array('Onemoguci' => 0, 'Omoguci (Identicno)' => 1, 'Omoguci (Pocetak Reci)' => 2, 'Omoguci (Deo Reci)' => 3),
    19 => array('Google' => 'google', 'Table' => 'table'),
    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2)
);

?>
